| Safe Haskell | Safe |
|---|---|
| Language | Haskell98 |
Text.Search.Sphinx.Indexable
Documentation
data SchemaType Source
Constructors
| TField | |
| TAttribute AttrT | |
| TFieldString |
class SphinxSchema a where Source
Methods
toDocument :: a -> (Id, [(String, Attr)]) Source
Convert a value of a to a document with a document id and some attributes and fields.
schema :: a -> [(String, SchemaType)] Source
The first parameter should be ignored, but is used to satisfy Haskell's type system.
serialize :: SphinxSchema a => [a] -> Element Source